==> pyxet-0.0.3-cp37-abi3-macosx_10_9_x86_64.macosx_11_0_arm64.macosx_10_9_universal2.whl: pyxet/__init__.py <==
from .file_system import open, login, XetFS

"""
PyXet
-----

pyxet is a Python package that provides an fsspec backend for interacting with repositories on 
XetHub. It allows users to work with files and directories on XetHub repositories using familiar 
file system operations such as open, ls, and glob. This package makes it easy to access and read 
data stored in XetHub repositories, both public and private, through a simple and intuitive API.

Main features:

1. pyxet.open: A function to open a file from a XetHub repository.
2. pyxet.XetFS: A class implementing fsspec.spec.AbstractFileSystem, 
   providing a file system handle for a XetHub repository.

To open a file from a XetHub repository, you can use the `pyxet.open()` 
function, which takes a file URL in the format 
`xet://<repo_user>/<repo_name>/<branch>/<path-to-file>`.  (See below for the URL format).

Example usage of `pyxet.open`:

```
import pyxet

# Open a file from a public repository.

f = pyxet.open('xet://xethub.com/XetHub/Flickr30k/main/results.csv')

# Read the contents of the file.
contents = f.read()
f.close()
```

To work with a XetHub repository as a file system, you can use the `pyxet.XetFS` class.
 This class provides a file system handle for a XetHub repository, allowing you to perform read-only operations like ls, glob, and open. The initialization of this class requires a repository URL and optional arguments for branch, user, and token.

Example usage of `pyxet.XetFS`:

```
import pyxet

# Create a file system handle for a public repository.
fs = pyxet.XetFS('xet://xethub.com/XetHub/Flickr30k/main/')

# List files in the repository.
files = fs.ls('/')

# Open a file from the repository.
f = fs.open('results.csv')

# Read the contents of the file.
contents = f.read()
```

For more information on the API and additional examples, refer to the documentation 
for `pyxet.open()` and `pyxet.XetFS.__init__()`, and the fsspec documentation. 

Fsspec Integration: 
-------------------

Many packages such as pandas and pyarrow support the fsspec protocol.  This means that 
xet:// urls can be used as file paths in these packages to refer directly to files in 
a XetHub repository.  For example, to read a csv from pandas, use: 

```
import pyxet
csv = pd.read_csv('xet://xethub.com/XetHub/Flickr30k/main/results.csv')
```

URLs:
-----

Xet URLs should be of the form `xet://<repo_user>/<repo_name>/<branch>/<path-to-file>`,
with the <path-to-file> being optional when opening a repository.  
The xet:// prefix is inferred as needed or if the url is given as https://.  
If branch is given as an explicit argument, it may be ommitted 
from the url.  

User and token are needed for private repositories.  They may be provided as 
explicit arguments to most pyxet functions, or they can be passed in with the URL by prefixing 
`xet://<user>[:token]@xethub.com/`.  For example, 
`xet://user1:mytokenxyz@xethub.com/data_user/data_repo/main/data/survey.csv` would
access the file `data/survey.csv` on the branch `main` of the repo `data_user/data_repo` 
with credentials `user=user1` and `token=mytokenxyz`. 

"""

==> pyxet-0.0.6-cp37-abi3-macosx_10_9_x86_64.macosx_11_0_arm64.macosx_10_9_universal2.whl: pyxet/__init__.py <==
from .file_system import open, login, XetFS

"""
PyXet
-----

pyxet is a Python package that provides an fsspec backend for interacting with repositories on 
XetHub. It allows users to work with files and directories on XetHub repositories using familiar 
file system operations such as open, ls, and glob. This package makes it easy to access and read 
data stored in XetHub repositories, both public and private, through a simple and intuitive API.

Main features:

1. pyxet.open: A function to open a file from a XetHub repository.
2. pyxet.XetFS: A class implementing fsspec.spec.AbstractFileSystem, 
   providing a file system handle for a XetHub repository.

To open a file from a XetHub repository, you can use the `pyxet.open()` 
function, which takes a file URL in the format 
`xet://<repo_user>/<repo_name>/<branch>/<path-to-file>`.  (See below for the URL format).

Example usage of `pyxet.open`:

```
import pyxet

# Open a file from a public repository.

f = pyxet.open('XetHub/Flickr30k/main/results.csv')

# Read the contents of the file.
contents = f.read()
f.close()
```

To work with a XetHub repository as a file system, you can use the `pyxet.XetFS` class.
 This class provides a file system handle for a XetHub repository, allowing you to perform read-only operations like ls, glob, and open. The initialization of this class requires a repository URL and optional arguments for branch, user, and token.

Example usage of `pyxet.XetFS`:

```
import pyxet

# Create a file system handle for a public repository.
fs = pyxet.XetFS()

# List files in the repository.
files = fs.ls('XetHub/Flickr30k/main')

# Open a file from the repository.
f = fs.open('XetHub/Flick30k/main/results.csv')

# Read the contents of the file.
contents = f.read()
```

For more information on the API and additional examples, refer to the documentation 
for `pyxet.open()` and `pyxet.XetFS.__init__()`, and the fsspec documentation. 

Fsspec Integration: 
-------------------

Many packages such as pandas and pyarrow support the fsspec protocol.  This means that 
xet:// urls can be used as file paths in these packages to refer directly to files in 
a XetHub repository.  For example, to read a csv from pandas, use: 

```
import pyxet
csv = pd.read_csv('xet://XetHub/Flickr30k/main/results.csv')
```

URLs:
-----

Xet URLs should be of the form `xet://<repo_user>/<repo_name>/<branch>/<path-to-file>`,
with the <path-to-file> being optional when opening a repository.  
The xet:// prefix is inferred as needed or if the url is given as https://.  
If branch is given as an explicit argument, it may be ommitted 
from the url.  

For private repos use pyxet.login to set authentication:
```
pyxet.login(user, token)
```
"""
